<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compresseur?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// C
	'compresseur_description' => '<code>ecrire/</code>と言うhtmlページや公開サイトのヘッダーにあるCSSとjavascriptの圧縮',
	'compresseur_slogan' => 'CSSとjavascriptの圧縮',
];
